@@ -9,7 +9,7 @@ knitr::opts_chunk$set(echo = TRUE,
                       dev = "png",
                       comment = "#>")
 library(rbioapi)
-rba_options(timeout = 600, skip_error = TRUE)
+rba_options(timeout = 30, skip_error = TRUE)
 
 ## ----rba_mieaa_cats, eval=FALSE-----------------------------------------------
 #  ## A list of available enrichment categories for:
@@ -37,8 +37,7 @@ mieaa_kegg <- rba_mieaa_enrich(test_set = mirs,
                               mirna_type = "mature",
                               test_type = "ORA",
                               species = 9606,
-                              categories = c("miRWalk_Diseases_mature",
-                                            "miRWalk_Organs_mature")
+                              categories = "KEGG_mature"
                              )
 
 ## ----mieaa_kegg_table, echo=FALSE---------------------------------------------
